#!/usr/bin/env bash
set -e

if command -v protoc &> /dev/null
then
  (
    cd third_party/tools
    ./build.sh
  )

  PATH="$PATH:$(pwd)/third_party/tools/bin" protoc \
    --proto_path=. \
    --go_out=. \
    --go_opt=paths=source_relative \
    ./third_party/solana_proto/confirmed_block/confirmed_block.proto
fi

# cargo install serde-generate
if command -v serdegen &> /dev/null
then
  serdegen ./pkg/gossip/schema.yaml \
    --language=Go \
    --with-runtimes=Bincode \
    --module-name=gossip \
    --serde-package-name=gossip \
    > ./pkg/gossip/schema.go
  sed -i'.bak' '1s/^/\/\/ Code generated by "serde-generate"; DO NOT EDIT.\n\n/' ./pkg/gossip/schema.go
  rm -f ./pkg/gossip/schema.go.bak
  go fmt ./pkg/gossip/schema.go
fi
